Struct AggregateEntry
pub struct AggregateEntry {
pub provider: Option<String>,
pub service: Option<String>,
pub resources: Option<Vec<ResourceEntry>>,
/* private fields */
}Fields
provider: Option<String>service: Option<String>resources: Option<Vec<ResourceEntry>>Trait Implementations
impl Clone for AggregateEntry
impl Clone for AggregateEntry
fn clone(&self) -> AggregateEntry
fn clone(&self) -> AggregateEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for AggregateEntry
impl Debug for AggregateEntry
impl<D> Decode<AggregateEntry, D> for AggregateEntrywhere
D: ResourceDialect,
impl<D> Decode<AggregateEntry, D> for AggregateEntrywhere
D: ResourceDialect,
fn new_empty() -> AggregateEntry
fn new_empty() -> AggregateEntry
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.impl Default for AggregateEntry
impl Default for AggregateEntry
fn default() -> AggregateEntry
fn default() -> AggregateEntry
Returns the “default value” for a type. Read more
impl<D> Encode<AggregateEntry, D> for &AggregateEntrywhere
D: ResourceDialect,
impl<D> Encode<AggregateEntry, D> for &AggregateEntrywhere
D: ResourceDialect,
impl PartialEq for AggregateEntry
impl PartialEq for AggregateEntry
impl Persistable for AggregateEntry
impl StructuralPartialEq for AggregateEntry
impl TypeMarker for AggregateEntry
impl TypeMarker for AggregateEntry
type Owned = AggregateEntry
type Owned = AggregateEntry
The owned Rust type which this FIDL type decodes into.
fn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
fn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.fn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read morefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl ValueTypeMarker for AggregateEntry
impl ValueTypeMarker for AggregateEntry
type Borrowed<'a> = &'a AggregateEntry
type Borrowed<'a> = &'a AggregateEntry
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read morefn borrow(
value: &<AggregateEntry as TypeMarker>::Owned,
) -> <AggregateEntry as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<AggregateEntry as TypeMarker>::Owned, ) -> <AggregateEntry as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for AggregateEntry
impl RefUnwindSafe for AggregateEntry
impl Send for AggregateEntry
impl Sync for AggregateEntry
impl Unpin for AggregateEntry
impl UnsafeUnpin for AggregateEntry
impl UnwindSafe for AggregateEntry