Struct ArmSmmu
#[repr(C)]pub struct ArmSmmu {
pub base_address: u64,
}Fields
base_address: u64Trait Implementations
impl Copy for ArmSmmu
impl<D> Decode<ArmSmmu, D> for ArmSmmuwhere
D: ResourceDialect,
impl<D> Decode<ArmSmmu, D> for ArmSmmuwhere
D: ResourceDialect,
impl Eq for ArmSmmu
impl Ord for ArmSmmu
impl Ord for ArmSmmu
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
impl PartialOrd for ArmSmmu
impl PartialOrd for ArmSmmu
impl Persistable for ArmSmmu
impl StructuralPartialEq for ArmSmmu
impl TypeMarker for ArmSmmu
impl TypeMarker for ArmSmmu
fn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
fn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.fn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read morefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for ArmSmmu
impl RefUnwindSafe for ArmSmmu
impl Send for ArmSmmu
impl Sync for ArmSmmu
impl Unpin for ArmSmmu
impl UnsafeUnpin for ArmSmmu
impl UnwindSafe for ArmSmmu