Struct BoardConfig
pub struct BoardConfig {
pub devices: Option<Vec<Device>>,
pub aggregates: Option<Vec<AggregateEntry>>,
/* private fields */
}Fields
devices: Option<Vec<Device>>aggregates: Option<Vec<AggregateEntry>>Trait Implementations
impl Clone for BoardConfig
impl Clone for BoardConfig
fn clone(&self) -> BoardConfig
fn clone(&self) -> BoardConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for BoardConfig
impl Debug for BoardConfig
impl<D> Decode<BoardConfig, D> for BoardConfigwhere
D: ResourceDialect,
impl<D> Decode<BoardConfig, D> for BoardConfigwhere
D: ResourceDialect,
fn new_empty() -> BoardConfig
fn new_empty() -> BoardConfig
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.impl Default for BoardConfig
impl Default for BoardConfig
fn default() -> BoardConfig
fn default() -> BoardConfig
Returns the “default value” for a type. Read more
impl<D> Encode<BoardConfig, D> for &BoardConfigwhere
D: ResourceDialect,
impl<D> Encode<BoardConfig, D> for &BoardConfigwhere
D: ResourceDialect,
impl PartialEq for BoardConfig
impl PartialEq for BoardConfig
impl Persistable for BoardConfig
impl StructuralPartialEq for BoardConfig
impl TypeMarker for BoardConfig
impl TypeMarker for BoardConfig
type Owned = BoardConfig
type Owned = BoardConfig
The owned Rust type which this FIDL type decodes into.
fn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
fn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.fn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read morefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl ValueTypeMarker for BoardConfig
impl ValueTypeMarker for BoardConfig
type Borrowed<'a> = &'a BoardConfig
type Borrowed<'a> = &'a BoardConfig
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read morefn borrow(
value: &<BoardConfig as TypeMarker>::Owned,
) -> <BoardConfig as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<BoardConfig as TypeMarker>::Owned, ) -> <BoardConfig as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for BoardConfig
impl RefUnwindSafe for BoardConfig
impl Send for BoardConfig
impl Sync for BoardConfig
impl Unpin for BoardConfig
impl UnsafeUnpin for BoardConfig
impl UnwindSafe for BoardConfig