Struct Iommu
pub struct Iommu {
pub name: Option<String>,
pub id: Option<u32>,
pub iommu_type: Option<IommuType>,
/* private fields */
}Fields
name: Option<String>id: Option<u32>iommu_type: Option<IommuType>Trait Implementations
impl<D> Decode<Iommu, D> for Iommuwhere
D: ResourceDialect,
impl<D> Decode<Iommu, D> for Iommuwhere
D: ResourceDialect,
impl Persistable for Iommu
impl StructuralPartialEq for Iommu
impl TypeMarker for Iommu
impl TypeMarker for Iommu
fn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
fn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.fn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read morefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for Iommu
impl RefUnwindSafe for Iommu
impl Send for Iommu
impl Sync for Iommu
impl Unpin for Iommu
impl UnsafeUnpin for Iommu
impl UnwindSafe for Iommu