Struct StaticMetadata
pub struct StaticMetadata {
pub id: Option<String>,
pub data: Option<Vec<u8>>,
/* private fields */
}Expand description
Metadata that is statically defined in the board configuration and passed to the device.
Fields
id: Option<String>data: Option<Vec<u8>>Trait Implementations
impl Clone for StaticMetadata
impl Clone for StaticMetadata
fn clone(&self) -> StaticMetadata
fn clone(&self) -> StaticMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for StaticMetadata
impl Debug for StaticMetadata
impl<D> Decode<StaticMetadata, D> for StaticMetadatawhere
D: ResourceDialect,
impl<D> Decode<StaticMetadata, D> for StaticMetadatawhere
D: ResourceDialect,
fn new_empty() -> StaticMetadata
fn new_empty() -> StaticMetadata
Creates a valid instance of
Self. The specific value does not matter,
since it will be overwritten by decode.impl Default for StaticMetadata
impl Default for StaticMetadata
fn default() -> StaticMetadata
fn default() -> StaticMetadata
Returns the “default value” for a type. Read more
impl<D> Encode<StaticMetadata, D> for &StaticMetadatawhere
D: ResourceDialect,
impl<D> Encode<StaticMetadata, D> for &StaticMetadatawhere
D: ResourceDialect,
impl PartialEq for StaticMetadata
impl PartialEq for StaticMetadata
impl Persistable for StaticMetadata
impl StructuralPartialEq for StaticMetadata
impl TypeMarker for StaticMetadata
impl TypeMarker for StaticMetadata
type Owned = StaticMetadata
type Owned = StaticMetadata
The owned Rust type which this FIDL type decodes into.
fn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
fn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.fn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read morefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.impl ValueTypeMarker for StaticMetadata
impl ValueTypeMarker for StaticMetadata
type Borrowed<'a> = &'a StaticMetadata
type Borrowed<'a> = &'a StaticMetadata
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read morefn borrow(
value: &<StaticMetadata as TypeMarker>::Owned,
) -> <StaticMetadata as ValueTypeMarker>::Borrowed<'_>
fn borrow( value: &<StaticMetadata as TypeMarker>::Owned, ) -> <StaticMetadata as ValueTypeMarker>::Borrowed<'_>
Cheaply converts from
&Self::Owned to Self::Borrowed.Auto Trait Implementations
impl Freeze for StaticMetadata
impl RefUnwindSafe for StaticMetadata
impl Send for StaticMetadata
impl Sync for StaticMetadata
impl Unpin for StaticMetadata
impl UnsafeUnpin for StaticMetadata
impl UnwindSafe for StaticMetadata