Struct StubIommu
pub struct StubIommu;Trait Implementations
impl Copy for StubIommu
impl<D> Decode<StubIommu, D> for StubIommuwhere
D: ResourceDialect,
impl<D> Decode<StubIommu, D> for StubIommuwhere
D: ResourceDialect,
impl Eq for StubIommu
impl Ord for StubIommu
impl Ord for StubIommu
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
impl PartialOrd for StubIommu
impl PartialOrd for StubIommu
impl Persistable for StubIommu
impl StructuralPartialEq for StubIommu
impl TypeMarker for StubIommu
impl TypeMarker for StubIommu
fn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
fn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.fn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read morefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Auto Trait Implementations
impl Freeze for StubIommu
impl RefUnwindSafe for StubIommu
impl Send for StubIommu
impl Sync for StubIommu
impl Unpin for StubIommu
impl UnsafeUnpin for StubIommu
impl UnwindSafe for StubIommu